==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/guestconfiguration/kotlin/inputs/GetGuestConfigurationAssignmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.guestconfiguration.kotlin.inputs

import com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property guestConfigurationAssignmentName The guest configuration assignment name.
 * @property resourceGroupName The resource group name.
 * @property vmName The name of the virtual machine.
 */
public data class GetGuestConfigurationAssignmentPlainArgs(
    public val guestConfigurationAssignmentName: String,
    public val resourceGroupName: String,
    public val vmName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs =
        com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs.builder()
            .guestConfigurationAssignmentName(guestConfigurationAssignmentName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .vmName(vmName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGuestConfigurationAssignmentPlainArgs].
 */
@PulumiTagMarker
public class GetGuestConfigurationAssignmentPlainArgsBuilder internal constructor() {
    private var guestConfigurationAssignmentName: String? = null

    private var resourceGroupName: String? = null

    private var vmName: String? = null

    /**
     * @param value The guest configuration assignment name.
     */
    @JvmName("gnhbjrrefplekdwb")
    public suspend fun guestConfigurationAssignmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.guestConfigurationAssignmentName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("dkjftmehkwvcvgqa")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the virtual machine.
     */
    @JvmName("usdqsowvxstukbqr")
    public suspend fun vmName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vmName = mapped
    }

    internal fun build(): GetGuestConfigurationAssignmentPlainArgs =
        GetGuestConfigurationAssignmentPlainArgs(
            guestConfigurationAssignmentName = guestConfigurationAssignmentName ?: throw
                PulumiNullFieldException("guestConfigurationAssignmentName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            vmName = vmName ?: throw PulumiNullFieldException("vmName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/guestconfiguration/kotlin/inputs/GetGuestConfigurationAssignmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.guestconfiguration.kotlin.inputs

import com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property guestConfigurationAssignmentName The guest configuration assignment name.
 * @property resourceGroupName The resource group name.
 * @property vmName The name of the virtual machine.
 */
public data class GetGuestConfigurationAssignmentPlainArgs(
    public val guestConfigurationAssignmentName: String,
    public val resourceGroupName: String,
    public val vmName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs =
        com.pulumi.azurenative.guestconfiguration.inputs.GetGuestConfigurationAssignmentPlainArgs.builder()
            .guestConfigurationAssignmentName(guestConfigurationAssignmentName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .vmName(vmName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGuestConfigurationAssignmentPlainArgs].
 */
@PulumiTagMarker
public class GetGuestConfigurationAssignmentPlainArgsBuilder internal constructor() {
    private var guestConfigurationAssignmentName: String? = null

    private var resourceGroupName: String? = null

    private var vmName: String? = null

    /**
     * @param value The guest configuration assignment name.
     */
    @JvmName("bemrybdomhasmldi")
    public suspend fun guestConfigurationAssignmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.guestConfigurationAssignmentName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("xwwwnbplknuosboc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the virtual machine.
     */
    @JvmName("dvaohgdcihlysefv")
    public suspend fun vmName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vmName = mapped
    }

    internal fun build(): GetGuestConfigurationAssignmentPlainArgs =
        GetGuestConfigurationAssignmentPlainArgs(
            guestConfigurationAssignmentName = guestConfigurationAssignmentName ?: throw
                PulumiNullFieldException("guestConfigurationAssignmentName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            vmName = vmName ?: throw PulumiNullFieldException("vmName"),
        )
}
